@@ -121,7 +121,7 @@ class CloudFilesStorage(Storage):
         if hasattr(content.file, 'content_type'):
             cloud_obj.content_type = content.file.content_type
         elif hasattr(content, 'content_type'):
-            cloud_obj.content = content.content_type
+            cloud_obj.content_type = content.content_type
         else:
             mime_type, encoding = mimetypes.guess_type(name)
             cloud_obj.content_type = mime_type
